class SystemPicture < ActiveRecord::Base
  has_many :balloons
  has_many :balloon_templates
  
  before_destroy :destroy_with_file
  
  def validate
    errors.add(:filesize, 'size over(1MB)') if self.filesize > 1000000
  end
  
  def destroy_with_file
    PictureIO.system_picture_io.delete self.filename
  end
  
  def dext
    self.ext.downcase
  end
  
  def filename
    "#{self.id}.#{self.dext}"
  end
  
  def mime_type
    "image/#{self.dext}"
  end
  
  def url
    '/system_pictures/' + filename
  end
  
  def store(rimg)
    bindata = rimg.to_blob
    PictureIO.system_picture_io.put bindata, self.filename
    true
  end
  
  def restore(subdir = nil)
    PictureIO.system_picture_io.get self.filename, subdir
  end
  
end
